@@ -331,7 +331,8 @@ class SerializeTestCase(unittest.TestCase):
         request.form['field_float_field'] = '2.71828'
         request.form['subfield_date_field_month'] = '11'
         request.form['subfield_date_field_day'] = '11'
-        request.form['subfield_date_field_year'] = '2022'
+        # This field only allows ten years in the future, today 2023-03-14
+        request.form['subfield_date_field_year'] = '2033'
         request.form['subfield_date_field_hour'] = '09'
         request.form['subfield_date_field_minute'] = '59'
         request.form['field_list_field'] = 'bar'
@@ -440,8 +441,8 @@ class SerializeTestCase(unittest.TestCase):
         XMLToForm(xml, form2)
 
         self.assertEqualForms(form, form2)
-        self.failIf(form2.has_field('another_field'))
-        self.failIf('another_field' in form2.objectIds())
+        self.assertFalse(form2.has_field('another_field'))
+        self.assertNotIn('another_field', form2.objectIds())
 
     def test_serializeDeserializeEncodedMessages(self):
         # test for serializing and deserializing XML with non-ascii text in
